@@ -1,5 +1,5 @@
 /*
- * $Id: messages.h,v 1.2 1996/09/15 11:36:25 lf Exp $
+ * $Id: messages.h,v 1.2 1997/12/25 23:28:05 lf Exp $
  *
  * Copyright (C) 1995,1996 Lars Fenneberg
  *
@@ -41,12 +41,6 @@
 
 #define SC_DEFAULT_ISSUE "(\\I)\r\n\r\n\\S \\R (\\N) (port \\L)\r\n\r\n"
 
-/* outbound.c */
-
-#define	SC_OUT_EXCEPTION	"ERROR unknown exception\r\n"
-#define	SC_OUT_READ			"ERROR write failed\r\n"
-#define	SC_OUT_WRITE		"ERROR read failed\r\n"
-
 /* radacct.c */
 
 #define SC_ACCT_OK	 "RADIUS accounting OK\r\n"
