@@ -1,5 +1,5 @@
 /*
- * $Id: sendserver.c,v 1.5 1998/06/27 17:41:15 lf Exp $
+ * $Id: sendserver.c,v 1.7 1999/01/16 19:55:04 lf Exp $
  *
  * Copyright (C) 1995,1996,1997 Lars Fenneberg
  *
@@ -173,10 +173,11 @@ int rc_send_server (SEND_DATA *data, char *msg)
 	int             total_length;
 	int             length;
 	int             retry_max;
+	int		secretlen;
 	char            secret[MAX_SECRET_LENGTH + 1];
 	unsigned char   vector[AUTH_VECTOR_LEN];
-	char            recv_buffer[1024];
-	char            send_buffer[1024];
+	char            recv_buffer[BUFFER_LEN];
+	char            send_buffer[BUFFER_LEN];
 	int		retries;
 	VALUE_PAIR 	*vp;
 
@@ -225,28 +226,32 @@ int rc_send_server (SEND_DATA *data, char *msg)
 	retry_max = data->retries;	/* Max. numbers to try for reply */
 	retries = 0;			/* Init retry cnt for blocking call */
 
-	/* Build an authentication request */
+	/* Build a request */
 	auth = (AUTH_HDR *) send_buffer;
 	auth->code = data->code;
-	rc_random_vector (vector);
 	auth->id = data->seq_nbr;
-	memcpy ((char *) auth->vector, (char *) vector, AUTH_VECTOR_LEN);
 
-#ifdef DIGEST_DEBUG
-        {
-        	int i;
-                        
-                fputs("auth->vector: ", stderr); 
-                for (i = 0; i < AUTH_VECTOR_LEN; i++) {
-                	fprintf(stderr,"%.2x ", (int) auth->vector[i]);
-		}
-		fputs("\n", stderr);
+	if (data->code == PW_ACCOUNTING_REQUEST)
+	{
+		total_length = rc_pack_list(data->send_pairs, secret, auth) + AUTH_HDR_LEN;
+
+		auth->length = htons ((unsigned short) total_length);
+		
+		memset((char *) auth->vector, 0, AUTH_VECTOR_LEN);
+		secretlen = strlen (secret);
+		memcpy ((char *) auth + total_length, secret, secretlen);
+		rc_md5_calc (vector, (char *) auth, total_length + secretlen);
+		memcpy ((char *) auth->vector, (char *) vector, AUTH_VECTOR_LEN);
 	}
-#endif
+	else
+	{
+		rc_random_vector (vector);
+		memcpy ((char *) auth->vector, (char *) vector, AUTH_VECTOR_LEN);
 
-	total_length = rc_pack_list(data->send_pairs, secret, auth) + AUTH_HDR_LEN;
+		total_length = rc_pack_list(data->send_pairs, secret, auth) + AUTH_HDR_LEN;
 
-	auth->length = htons ((unsigned short) total_length);
+		auth->length = htons ((unsigned short) total_length);
+	}
 
 	sin = (struct sockaddr_in *) & saremote;
 	memset ((char *) sin, '\0', sizeof (saremote));
@@ -305,10 +310,10 @@ int rc_send_server (SEND_DATA *data, char *msg)
 	
 	recv_auth = (AUTH_HDR *)recv_buffer;
 	
-	data->receive_pairs = rc_avpair_gen(recv_auth);
-	
 	result = rc_check_reply (recv_auth, secret, vector, data->seq_nbr);
 
+	data->receive_pairs = rc_avpair_gen(recv_auth);
+
 	close (sockfd);
 	memset (secret, '\0', sizeof (secret));
 
@@ -321,6 +326,7 @@ int rc_send_server (SEND_DATA *data, char *msg)
 		if ((vp = rc_avpair_get(vp, PW_REPLY_MESSAGE)))
 		{
 			strcat(msg, vp->strvalue);
+			strcat(msg, "\n");
 			vp = vp->next;
 		}
 	}
