@@ -1,5 +1,5 @@
 /*
- * $Id: local.c,v 1.2 1996/09/15 11:36:36 lf Exp $
+ * $Id: local.c,v 1.2 1997/12/25 23:28:54 lf Exp $
  *
  * Copyright (C) 1996 Lars Fenneberg
  *
@@ -9,21 +9,15 @@
  *
  */
 
-#include <syslog.h>
-#include <unistd.h>
-#include <pwd.h>
-#include <errno.h>
+#include <config.h>
+#include <includes.h>
+#include <radiusclient.h>
+#include <messages.h>
+#include <radlogin.h>
 
-#include <sys/types.h>
-
-#include "config.h"
-#include "radius.h"
-#include "messages.h"
-#include "radlogin.h"
-
-#ifdef SHADOW_PASSWORD
+#ifdef HAVE_SHADOW_PASSWORDS
 #include <shadow.h>
-#endif
+#endif /* HAVE_SHADOW_PASSWORDS */
 
 extern ENV *env;
 
@@ -31,7 +25,7 @@ LFUNC auth_local(char *username, char *passwd)
 {
 	struct passwd	*pw;
 	char		*xpasswd;
-#ifdef SHADOW_PASSWORD
+#ifdef HAVE_SHADOW_PASSWORDS
 	struct spwd	*spw;
 #endif
 
@@ -43,7 +37,7 @@ LFUNC auth_local(char *username, char *passwd)
 	}
 	endpwent();
 	
-#ifdef SHADOW_PASSWORD
+#ifdef HAVE_SHADOW_PASSWORDS
         if((spw = getspnam(pw->pw_name)) == NULL) {
 			endspent();
 			rc_log(LOG_NOTICE, "authentication FAILED, type local, username %s", username);
@@ -55,7 +49,7 @@ LFUNC auth_local(char *username, char *passwd)
         	pw->pw_passwd = spw->sp_pwdp; 
         }
         endspent();
-#endif /* SHADOW_PASSWORD */
+#endif /* HAVE_SHADOW_PASSWORDS */
 
 	xpasswd = crypt(passwd, pw->pw_passwd);
 	
